@@ -4,7 +4,7 @@ import os
 
 from almost_empty import python, tex
 
-__version__ = '0.2.3-beta'
+__version__ = '0.3.0-beta'
 
 
 def get_params():
@@ -38,6 +38,8 @@ def execute_from_command_line():
 		python.pure(name, directory, repo)
 	elif language[0] == 'django':
 		python.django(name, directory, repo)
+	elif language[0] == 'flask':
+		python.flask(name, directory, repo)
 	elif language[0] == 'tex':
 		tex.pure(name, directory, repo)
 	else:
